import React, { useEffect } from "react";
import { useLocation } from "react-router-dom";
import SEOHead from "@/components/SEOHead";
import Header from "@/components/Header";
import Hero from "@/components/Hero";
import Features from "@/components/Features";
import Process from "@/components/Process";
import Location from "@/components/Location";
import Pricing from "@/components/Pricing";
import FAQ from "@/components/FAQ";
import Testimonials from "@/components/Testimonials";
import Contact from "@/components/Contact";

interface LocationState {
  scrollToId?: string;
}

const Index: React.FC = () => {
  const location = useLocation();

  // Scroll to section if navigated from another page with a scrollToId in state
  useEffect(() => {
    const state = location.state as LocationState;
    if (state?.scrollToId) {
      setTimeout(() => {
        const element = document.getElementById(state.scrollToId);
        if (element) {
          window.scrollTo({
            top: element.offsetTop - 80,
            behavior: 'smooth'
          });
        }
        
        // Clear the state to prevent scrolling on refresh
        window.history.replaceState({}, document.title);
      }, 100); // Small delay to ensure DOM is fully loaded
    }
  }, [location]);

  // Structured data for homepage
  const homepageStructuredData = {
    "@context": "https://schema.org",
    "@type": "WebSite",
    "name": "DeinMietgarten",
    "url": "https://deinmietgarten.de",
    "description": "Miete deine eigene Gartenparzelle in der Stadt. Baue biologisches Gemüse, Kräuter und Blumen mit DeinMietgarten Premium-Urban-Gärten an.",
    "potentialAction": {
      "@type": "SearchAction",
      "target": "https://deinmietgarten.de/pflanzen?search={search_term_string}",
      "query-input": "required name=search_term_string"
    },
    "mainEntity": {
      "@type": "Service",
      "name": "Gartenparzellen Vermietung",
      "description": "Premium Urban-Gartenparzellen zur Miete für den Anbau von biologischem Gemüse",
      "provider": {
        "@type": "Organization",
        "name": "DeinMietgarten"
      },
      "areaServed": "Augsburg-Inningen, Deutschland",
      "hasOfferCatalog": {
        "@type": "OfferCatalog",
        "name": "Gartenparzellen",
        "itemListElement": [
          {
            "@type": "Offer",
            "itemOffered": {
              "@type": "Service",
              "name": "Kleine Parzelle (20m²)"
            }
          },
          {
            "@type": "Offer", 
            "itemOffered": {
              "@type": "Service",
              "name": "Mittlere Parzelle (40m²)"
            }
          },
          {
            "@type": "Offer",
            "itemOffered": {
              "@type": "Service", 
              "name": "Große Parzelle (80m²)"
            }
          }
        ]
      }
    }
  };

  return (
    <div className="min-h-screen flex flex-col bg-white overflow-x-hidden relative">
      <SEOHead
        title="DeinMietgarten - Miete deine eigene Gartenparzelle in Augsburg-Inningen"
        description="Miete deine eigene Ackerparzelle zum Gemüse anbauen in Augsburg-Inningen. Auf vorbereiteten Böden startest du direkt mit der Aussaat und erntest eine ganze Saison lang dein eigenes Bio-Gemüse."
        keywords="Gartenparzelle mieten, Urban Gardening Augsburg, Bio-Gemüse anbauen, Selbstversorgung, Ackerparzelle, Gemüsegarten mieten, Augsburg-Inningen"
        structuredData={homepageStructuredData}
      />
      
      {/* Simplified background effects for better mobile compatibility and performance */}
      <div className="absolute inset-0 -z-10 bg-white"></div>
      <div className="absolute top-0 right-0 w-full md:w-1/2 h-[50vh] md:h-screen -z-9 bg-gradient-to-b from-accent/10 via-transparent to-transparent opacity-50"></div>
      <div className="absolute bottom-0 left-0 w-full md:w-1/2 h-[50vh] md:h-screen -z-9 bg-gradient-to-t from-primary/5 via-transparent to-transparent opacity-50"></div>
      
      <Header />
      <main className="overflow-x-hidden">
        <Hero />
        <Features />
        <Process />
        <Location />
        <Pricing />
        <FAQ />
        <Testimonials />
        <Contact />
      </main>
    </div>
  );
};

export default Index;
